@@ -5,18 +5,18 @@ import (
 
 	"net/http"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/segments/options"
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
 )
 
 type HTTP struct {
-	base
+	Base
 
-	Body map[string]interface{}
+	Body map[string]any
 }
 
 const (
-	METHOD properties.Property = "method"
+	METHOD options.Option = "method"
 )
 
 func (h *HTTP) Template() string {
@@ -24,18 +24,14 @@ func (h *HTTP) Template() string {
 }
 
 func (h *HTTP) Enabled() bool {
-	url := h.props.GetString(URL, "")
-	if len(url) == 0 {
+	url := h.options.String(URL, "")
+	if url == "" {
 		return false
 	}
 
-	method := h.props.GetString(METHOD, "GET")
+	method := h.options.String(METHOD, "GET")
 
-	tmpl := &template.Text{
-		Template: url,
-	}
-
-	if resolved, err := tmpl.Render(); err == nil {
+	if resolved, err := template.Render(url, nil); err == nil {
 		url = resolved
 	}
 
@@ -48,7 +44,7 @@ func (h *HTTP) Enabled() bool {
 	return true
 }
 
-func (h *HTTP) getResult(url, method string) (map[string]interface{}, error) {
+func (h *HTTP) getResult(url, method string) (map[string]any, error) {
 	setMethod := func(request *http.Request) {
 		request.Method = method
 	}
@@ -58,7 +54,7 @@ func (h *HTTP) getResult(url, method string) (map[string]interface{}, error) {
 		return nil, err
 	}
 
-	var result map[string]interface{}
+	var result map[string]any
 	err = json.Unmarshal(resultBody, &result)
 	if err != nil {
 		return nil, err
